# Architecture Decision Records

| ADR | Title | Status |
|-----|-------|--------|
| [ADR-0001](0001-live-tui-for-orc-run.md) | Live TUI for `orc run` | Accepted |
| [ADR-0003](0003-mcp-server-and-squad-permissions.md) | MCP Server and Squad Permissions | Accepted |
